===============
intake-forecast
===============

Intake driver for cyclic zarr sources

.. image:: https://img.shields.io/pypi/v/intake-forecast.svg
    :target: https://pypi.org/project/intake-forecast/
.. image:: https://img.shields.io/pypi/dm/intake-forecast
    :target: https://pypistats.org/packages/intake-forecast
    :alt: PyPI - Downloads
.. image:: https://img.shields.io/pypi/pyversions/intake-forecast
    :target: https://pypi.org/project/intake-forecast/
    :alt: PyPI - Python Version
